# retico-core

[![Documentation Status](https://readthedocs.org/projects/retico-core/badge/?version=latest)](https://retico-core.readthedocs.io/en/latest/?badge=latest)

This project includes the core functionality of the retico framework. This includes the
abstract, general definitions of incremental modules and incremental units (IUs), as
well as modules and IUs for audio input/output, debugging, dialogue, and text
processing. Also, some tools for saving and loading modules to and from file are
available.

For the main repository that includes a variety of useful modules and IU definitions, 
go to [github.com/retico-team/retico](https://github.com/retico-team/retico).

## How to install

For installing retico-core, you need to have `portaudio` installed. See the
documentation for a detailed description of how to install it. Then, you can install it
via pip:

```bash
$ pip install retico-core
```

## Documentation

The documentation of retico-core can be found at [https://retico-core.readthedocs.io/](https://retico-core.readthedocs.io/)

## Import
```
import retico_core.core.abstract
import retico_core.core.audio
import retico_core.core.debug
import retico_core.core.dialogue
import retico_core.core.network
import retico_core.core.text
import retico_core.core.visual
```

## Pip Deployment
* rm -rf dist

* python -m build --sdist

* twine upload dist/*